```{hint}
Start with the [getting started] tutorial, the [cheatsheet], or...

~~~{button-link} ./demo.html
:color: primary
:expand:
Try **doitoml** Now
~~~
```

```{grid} 2

  ~~~{grid-item-card}  tutorials
  :link: ./tutorials/index.html
  learning-oriented tutorials
  ~~~
  ~~~{grid-item-card}  how-to
  :link: ./how-to/index.html
  goal-oriented how-to guides
  ~~~
```

```{grid} 2
  ~~~{grid-item-card}  understanding
  :link: ./understanding/index.html
  understanding-oriented discussions
  ~~~
  ~~~{grid-item-card}  reference
  :link: ./reference/index.html
  information-oriented reference material
  ~~~
```

```{include} ../README.md

```

## documentation contents

```{toctree}
:maxdepth: 2

demo
tutorials/index
how-to/index
understanding/index
reference/index
```

[getting started]: ./tutorials/getting-started.ipynb
[cheatsheet]: ./reference/cheatsheet.md
